@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,13 +13,14 @@ FilterIcedove::FilterIcedove()
 {
     setName(i18n("Import Icedove Mails and Folder Structure"));
     setAuthor(QStringLiteral("Laurent Montel"));
-    setInfo(i18n("<p><b>Icedove import filter</b></p>"
-                 "<p>Select your base Icedove mailfolder"
-                 " (usually ~/.icedove/*.default/Mail/Local Folders/).</p>"
-                 "<p><b>Note:</b> Never choose a Folder which <u>does not</u> contain mbox-files (for example,"
-                 " a maildir): if you do, you will get many new folders.</p>"
-                 "<p>Since it is possible to recreate the folder structure, the folders "
-                 "will be stored under: \"Icedove-Import\".</p>"));
+    setInfo(
+        i18n("<p><b>Icedove import filter</b></p>"
+             "<p>Select your base Icedove mailfolder"
+             " (usually ~/.icedove/*.default/Mail/Local Folders/).</p>"
+             "<p><b>Note:</b> Never choose a Folder which <u>does not</u> contain mbox-files (for example,"
+             " a maildir): if you do, you will get many new folders.</p>"
+             "<p>Since it is possible to recreate the folder structure, the folders "
+             "will be stored under: \"Icedove-Import\".</p>"));
 }
 
 FilterIcedove::~FilterIcedove()
